@@ -126,21 +126,22 @@ static int smb_parse_options(char *optstr,char **argv,char *qbuf,int *qbuflen)
 int mount_mount(char *root, char *name, int name_len, char *what,
 		char *fstype, char *options, void *context)
 {
-  char *fullpath;
+  char *fullpath, *optcopy;
   int err;
   char *qbuf;
-  int argc, qbuflen;
+  int argc, optsize, qbuflen;
   char **argv;
 
   fullpath = alloca(strlen(root)+name_len+2);
-  if ( !fullpath ) {
+  optcopy  = alloca(optsize = strlen(options)+1);
+  if ( !fullpath || !optcopy ) {
     syslog(LOG_ERR, MODPREFIX "alloca: %m");
     return 1;
   }
   sprintf(fullpath, "%s/%s", root, name);
 
-  /* FIXME: This assumes "options" is writable, possibly a bad assumption */
-  argc = smb_parse_options(options, NULL, NULL, &qbuflen) + 4;
+  memcpy(optcopy, options, optsize);
+  argc = smb_parse_options(optcopy, NULL, NULL, &qbuflen) + 4;
   argv = alloca(sizeof(char *) * argc);
   qbuf = alloca(qbuflen);
   if ( !argv || (qbuflen && !qbuf) ) {
@@ -150,7 +151,8 @@ int mount_mount(char *root, char *name, int name_len, char *what,
   argv[0] = _PATH_SMBMOUNT;
   argv[1] = what;
   argv[2] = fullpath;
-  smb_parse_options(options, argv+3, qbuf, NULL);
+  memcpy(optcopy, options, optsize);
+  smb_parse_options(optcopy, argv+3, qbuf, NULL);
 
   syslog(LOG_DEBUG, MODPREFIX "calling mkdir %s", fullpath);
   if ( mkdir(fullpath, 0555) && errno != EEXIST ) {
